ReportLab Preppy Test Suite 009

# Preppy Test 009 - Testing Preppy With Things That Look Like Floating Point Numbers

This tests to see if Preppy can handle being passed a dictionary with keys that are actually strings, but that look like floating point numbers.

## Expected Output

You should see four lines of text between these lines.

    This should print the number 1.01: 1.01
    This should print the number 2.78: 2.78

    This should print the string in key 1.01, but is still plain daft:
        The key for this dictionary item looks like a number, but is actually a string
    This should print the string in key 2.78 and is still equally daft:
        So is this one - it looks like a floating point number